---
name: Bug Report
about: File a bug report. (Please search exisiting issues before submitting. Also see CONTRIBUTING.md.)
title: ""
labels: bug
assignees: ""
---

## Summary

<!--
    What went wrong? What is the current behavior?
    Please be as clear and concise as possible.
-->

## Expected Behavior

<!--
    What did you expect to happen?
-->

## Steps to Reproduce Behavior

<!--
    If possible, please share the steps to reproduce the issue.
    If relevant, feel free to include any code that reliably reproduces the issue.
-->

### Solution

<!--
    If you have any suggestions on fixing the issue.
-->

## Environment

- Version: <!-- [e.g. 0.1.0] -->
- OS and Python version: <!-- [e.g. Linux/Python 3.8.7] -->

## Additional Context

<!--
    Append any additional context regarding the problem here.
    Screenshots are always welcome!
-->
